@@ -760,20 +760,11 @@ class TestResults:
             params=None,
         )
 
-    def test_get_plan(self, results, response, get, mocker):
-        url = results.tuxapi_url + "/v1/groups/{}/projects/{}/plans/{}".format(
-            results.group, results.project, results.uid
-        )
-        response._content = b'{"a": "b"}'
-
-        assert response.status_code == 200
-        assert results.get_plan() == ({"a": "b"}, url.replace("plans", "tests"))
-        get.assert_called_with(
-            url,
-            headers=results.headers,
-            timeout=mocker.ANY,
-            params=None,
-        )
+    def test_get_plan(self, results, mocker):
+        get_plan = mocker.patch("tuxsuite.build.Plan.get_plan")
+        result = results.get_plan()
+        assert get_plan.call_count == 1
+        assert isinstance(result, type(()))
 
     def test_get_all(self, results, response, get):
         response._content = b'{"a": "b"}'
