@@ -28,4 +28,4 @@ def test_new_build(config, params):
 
 def test_new_build_set(config, params):
     build_set = tuxsuite.BuildSet([params])
-    assert build_set.kbapi_url is not None
+    assert build_set.tuxapi_url is not None
