@@ -439,7 +439,7 @@ class Plan(HeadersMixin):
         self.project = kwargs["project"]
         self.group = kwargs["group"]
         self.args = kwargs
-        self.plan = None
+        self.plan = kwargs.get("plan", None)
         self.builds = []
         self.tests = []
         self.status = {}
@@ -549,12 +549,12 @@ class Plan(HeadersMixin):
             )
             if first or start_builds is not None:
                 builds.update({b["uid"]: b for b in ret["builds"]["results"]})
+                start_builds = ret["builds"]["next"]
             if first or start_tests is not None:
                 tests.update({t["uid"]: t for t in ret["tests"]["results"]})
+                start_tests = ret["tests"]["next"]
 
             first = False
-            start_builds = ret["builds"]["next"]
-            start_tests = ret["tests"]["next"]
 
         self.status = {"builds": builds, "tests": tests}
         return self.status
@@ -565,7 +565,7 @@ class Plan(HeadersMixin):
 
         while True:
             plan = self.get_plan()
-            for build in self.builds:
+            for build in [b for b in self.builds if b.uid in plan["builds"]]:
                 if build.uid not in self.results["builds"]:
                     build.status = plan["builds"][build.uid]
                     if not hasattr(build, "ite"):
@@ -576,7 +576,7 @@ class Plan(HeadersMixin):
                         yield state
                         if state.final:
                             self.results["builds"][build.uid] = state
-            for test in self.tests:
+            for test in [t for t in self.tests if t.uid in plan["tests"]]:
                 if test.uid not in self.results["tests"]:
                     test.get = lambda: plan["tests"][test.uid]
                     if not hasattr(test, "ite"):
@@ -758,11 +758,17 @@ class Results(HeadersMixin):
         return (result, url)
 
     def get_plan(self):
-        url = self.tuxapi_url + "/v1/groups/{}/projects/{}/plans/{}".format(
-            self.group, self.project, self.uid
+        plan = Plan(
+            None,
+            token=self.token,
+            tuxapi_url=self.tuxapi_url,
+            project=self.project,
+            group=self.group,
+            plan=self.uid,
         )
-        result = get_request(url, self.headers)
-        return (result, url.replace("plans", "tests"))
+        # TODO: Return the test url as part of the test result in tuxapi
+        tuxapi_tests_url = plan.url + "/tests"
+        return (plan.get_plan(), tuxapi_tests_url)
 
     def get_all(self):
         all_results = {}
