@@ -322,6 +322,7 @@ def build(
     )
     try:
         build.build()
+        info("uid: {}".format(build.uid))
     except tuxsuite.exceptions.BadRequest as e:
         raise (click.ClickException(str(e)))
 
@@ -425,12 +426,20 @@ DEVICES = [
     "qemu-mips64el",
     "qemu-powerpc",
     "qemu-ppc64",
+    "qemu-ppc64le",
     "qemu-riscv",
     "qemu-riscv64",
     "qemu-sparc64",
     "qemu-x86_64",
 ]
-TESTS = ["boot", "ltp-smoke"]
+TESTS = [
+    "boot",
+    "ltp-fcntl-locktests",
+    "ltp-fs_bind",
+    "ltp-fsx",
+    "ltp-nptl",
+    "ltp-smoke",
+]
 
 
 @cli.command(help="Test a kernel", short_help="Test a kernel")
@@ -499,6 +508,7 @@ def test(device, kernel, modules, tests, boot_args, wait_for, no_wait, json_out)
 
     try:
         test.test()
+        info("uid: {}".format(test.uid))
     except tuxsuite.exceptions.BadRequest as e:
         raise (click.ClickException(str(e)))
 
@@ -602,6 +612,7 @@ def plan(
     try:
         plan.submit()
         info("Plan {}/plans/{}\n".format(plan.url, plan.plan))
+        info("uid: {}".format(plan.plan))
     except tuxsuite.exceptions.BadRequest as e:
         raise (click.ClickException(str(e)))
 
@@ -695,10 +706,13 @@ def results(build, test, plan, from_json, json_out):
         if plan:
             results.uid = plan
             result_json, tuxapi_tests_url = results.get_plan()
-            for result in result_json["builds"].get("results", None):
-                format_result(result)
-            for result in result_json["tests"].get("results", None):
-                format_result(result, tuxapi_tests_url=tuxapi_tests_url)
+            for result in result_json["builds"].keys():
+                format_result(result_json["builds"][result])
+            for result in result_json["tests"].keys():
+                format_result(
+                    result_json["tests"][result],
+                    tuxapi_tests_url + "/{}".format(result),
+                )
     except tuxsuite.exceptions.URLNotFound as e:
         raise (click.ClickException(str(e)))
 
